package com.agri.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.agri.system.domain.SysImeiAutoLog;

/**
 * 自动模式日志Service接口
 * 
 * @author lld
 * @date 2026-03-29
 */
public interface ISysImeiAutoLogService  extends IService<SysImeiAutoLog> {
    /**
     * 查询自动模式日志
     * 
     * @param id 自动模式日志主键
     * @return 自动模式日志
     */
    public SysImeiAutoLog selectSysImeiAutoLogById(Long id);

    /**
     * 查询自动模式日志列表
     * 
     * @param sysImeiAutoLog 自动模式日志
     * @return 自动模式日志集合
     */
    public List<SysImeiAutoLog> selectSysImeiAutoLogList(SysImeiAutoLog sysImeiAutoLog);

    /**
     * 新增自动模式日志
     * 
     * @param sysImeiAutoLog 自动模式日志
     * @return 结果
     */
    public int insertSysImeiAutoLog(SysImeiAutoLog sysImeiAutoLog);

    /**
     * 修改自动模式日志
     * 
     * @param sysImeiAutoLog 自动模式日志
     * @return 结果
     */
    public int updateSysImeiAutoLog(SysImeiAutoLog sysImeiAutoLog);

    /**
     * 批量删除自动模式日志
     * 
     * @param ids 需要删除的自动模式日志主键集合
     * @return 结果
     */
    public int deleteSysImeiAutoLogByIds(Long[] ids);

    /**
     * 删除自动模式日志信息
     * 
     * @param id 自动模式日志主键
     * @return 结果
     */
    public int deleteSysImeiAutoLogById(Long id);
}
